#
# spec file for package kdepim-runtime
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0
%define kpim6_version 6.3.3

%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150500
%bcond_without etebase
%endif

%bcond_with kolabxml
%bcond_without released
Name:           kdepim-runtime
Version:        24.12.3
Release:        1.2
Summary:        Akonadi resources for PIM applications
License:        GPL-2.0-or-later AND GPL-3.0-or-later
URL:            https://www.kde.org
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  cyrus-sasl-devel
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  libboost_atomic-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libboost_system-devel
%if %{with etebase}
BuildRequires:  libetebase-devel
%endif
%if %{with kolabxml}
BuildRequires:  libkolabxml-devel >= 1.1
%endif
BuildRequires:  shared-mime-info
BuildRequires:  cmake(KF6CalendarCore) >= %{kf6_version}
BuildRequires:  cmake(KF6Codecs) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6Contacts) >= %{kf6_version}
BuildRequires:  cmake(KF6DAV) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6Holidays) >= %{kf6_version}
BuildRequires:  cmake(KF6ItemModels) >= %{kf6_version}
BuildRequires:  cmake(KF6KCMUtils) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6NotifyConfig) >= %{kf6_version}
BuildRequires:  cmake(KF6Wallet) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KPim6Akonadi) >= %{kpim6_version}
BuildRequires:  cmake(KPim6AkonadiCalendar) >= %{kpim6_version}
BuildRequires:  cmake(KPim6AkonadiContactWidgets) >= %{kpim6_version}
BuildRequires:  cmake(KPim6AkonadiMime) >= %{kpim6_version}
BuildRequires:  cmake(KPim6CalendarUtils) >= %{kpim6_version}
BuildRequires:  cmake(KPim6GAPI) >= %{kpim6_version}
BuildRequires:  cmake(KPim6IMAP) >= %{kpim6_version}
BuildRequires:  cmake(KPim6IdentityManagementWidgets) >= %{kpim6_version}
BuildRequires:  cmake(KPim6LdapWidgets) >= %{kpim6_version}
BuildRequires:  cmake(KPim6MailTransport) >= %{kpim6_version}
BuildRequires:  cmake(KPim6Mbox) >= %{kpim6_version}
BuildRequires:  cmake(KPim6Mime) >= %{kpim6_version}
BuildRequires:  cmake(Qca-qt6)
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Keychain)
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6NetworkAuth) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6TextToSpeech) >= %{qt6_version}
BuildRequires:  cmake(Qt6WebEngineWidgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
Recommends:     kalendarac
Requires:       akonadi
Requires:       akonadi-plugin-calendar
Requires:       akonadi-plugin-contacts
Requires:       akonadi-plugin-mime
Provides:       kio-pimlibs = %{version}
Obsoletes:      kdepim4-runtime < %{version}
Obsoletes:      kio-pimlibs < %{version}
# It can only build on the same platforms as Qt Webengine
ExclusiveArch:  x86_64 %{x86_64} aarch64 riscv64

%description
This package contains the Akonadi resources, agents and plugins needed to
use PIM applications.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-html --all-name

%ldconfig_scriptlets

%files
%license LICENSES/*
%{_kf6_applicationsdir}/org.kde.akonadi_contacts_resource.desktop
%{_kf6_applicationsdir}/org.kde.akonadi_davgroupware_resource.desktop
%{_kf6_applicationsdir}/org.kde.akonadi_ews_resource.desktop
%{_kf6_applicationsdir}/org.kde.akonadi_google_resource.desktop
%{_kf6_applicationsdir}/org.kde.akonadi_imap_resource.desktop
%if %{with kolabxml}
%{_kf6_applicationsdir}/org.kde.akonadi_kolab_resource.desktop
%endif
%{_kf6_applicationsdir}/org.kde.akonadi_openxchange_resource.desktop
%{_kf6_applicationsdir}/org.kde.akonadi_vcard_resource.desktop
%{_kf6_applicationsdir}/org.kde.akonadi_vcarddir_resource.desktop
%{_kf6_bindir}/akonadi_*
%{_kf6_bindir}/gidmigrator
%{_kf6_dbusinterfacesdir}/org.kde.Akonadi.Maildir.Settings.xml
%{_kf6_dbusinterfacesdir}/org.kde.Akonadi.MixedMaildir.Settings.xml
%{_kf6_debugdir}/kdepim-runtime.categories
%{_kf6_debugdir}/kdepim-runtime.renamecategories
%if %{with etebase}
%{_kf6_iconsdir}/hicolor/*/apps/akonadi-etesync.png
%endif
%{_kf6_iconsdir}/hicolor/*/apps/akonadi-ews.png
%{_kf6_iconsdir}/hicolor/*/apps/ox.png
%{_kf6_libdir}/*
%{_kf6_notificationsdir}/akonadi_*.notifyrc
%dir %{_kf6_plugindir}/pim6
%dir %{_kf6_plugindir}/pim6/akonadi
%dir %{_kf6_plugindir}/pim6/akonadi/config
%{_kf6_plugindir}/pim6/akonadi/config/*.so
%dir %{_kf6_plugindir}/pim6/kcms
%dir %{_kf6_plugindir}/pim6/kcms/kaddressbook/
%dir %{_kf6_plugindir}/pim6/mailtransport
%{_kf6_plugindir}/pim6/mailtransport/mailtransport_akonadiplugin.so
%{_kf6_sharedir}/akonadi/
%{_kf6_sharedir}/mime/packages/kdepim-mime.xml

%files lang -f %{name}.lang

%changelog
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- Changes since 24.12.2:
  * urlconfigurationdialog.ui - move the protocol buttons into a QButtonGroup (kde#455787)
  * Don't access payload when it's not available (kde#490307)
  * agents/newmailnotifier: use <br/> for notifications
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- Changes since 24.12.0:
  * Remove superfluous debug messages
  * Dav: fix updating categories on tags change
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- Changes since 24.11.90:
  * iCal: propagate updated categories back to Akonadi
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- No code change since 24.11.80
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Too many changes since 24.08.3, only listing bugfixes:
  * Fix crash in iCal Categories to Tags migrator on payload mismatch (kde#492281)
  * EWS: Check that mEventReq is not null in EwsSubscriptionManager (kde#495155)
  * Forward network error to the resouce (kde#485799)
  * ews: Bound check calendar events (kde#491810)
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- Changes since 24.08.2:
  * EWS: Check that mEventReq is not null in EwsSubscriptionManager (kde#495155)
  * It generates warning
* Thu Oct 10 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Make use of libkolabxml optional (boo#1060506)
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- Changes since 24.08.1:
  * EWS: don't do autodiscovery when using Office365 OAuth
  * EWS: fix crash when autodisovery or connection fails
  * Attempt to workaround EWS servers sometimes returning broken iCal (kde#491681)
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- Changes since 24.08.0:
  * Forward network error to the resouce (kde#485799)
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Too many changes since 24.05.2, only listing bugfixes:
  * SingleFileResource: trigger sync after initially loading file on start (kde#485761)
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- Changes since 24.05.1:
  * Add default destructor to TransferJob
  * Do not try to subscribe to an empty list of folders
  * Fix a memory leak in TransferJob
  * Google: explicitly request calendar.events scope in authentication
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Changes since 24.04.80:
  * SingleFileResource: trigger sync after initially loading file on start (kde#485761)
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes since 24.02.2, only listing bugfixes:
  * Bring back etesync support (kde#482600)
  * Fix endless sync loop with some remote iCal sources (kde#384309)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Bring back etesync support (kde#482600)
  * Support NTLMv2
  * Port EWS resource away from KIO Http
  * Fix endless sync loop with some remote iCal sources (kde#384309)
- Drop patch, merged upstream:
  * 0001-Bring-back-etesync-support.patch
* Wed Mar 13 2024 Christophe Marin <christophe@krop.fr>
- Add upstream change to fix the etesync resource build (kde#482600):
  * 0001-Bring-back-etesync-support.patch
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Fix EWS config dialog
  * ews: Handle KIO::ERR_ACCESS_DENIED error
  * ews: Use http1 for ews requests
  * Move checkbox on top
  * Fix start service
  * Comment this assert. we need to investigate more.
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- Changes since 23.08.3:
  * Add default ews base url
  * Correctly reload configuration (kde#473897)
  * Don't destroy save password job before closing the save dialog
  * Do not read google password from wallet when account is not configured
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- No code change since 23.08.2
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * Fix reading DAV provider properties
  * Fix kpimtextedit dependency
  * Actually start job to read secret key (kde#470820)
  * Revert "Revert "Fix race condition when building""
  * Revert "Revert "Use config plugin instead of out of process config dialog""
  * Fix signal/slot
- Drop patches, merged upstream:
  * 0001-Revert-Revert-Use-config-plugin-instead-of-out-of-pr.patch
  * 0002-Revert-Revert-Fix-race-condition-when-building.patch
  * 0003-Actually-start-job-to-read-secret-key.patch
* Tue Sep 26 2023 Bob Haley <fawz@use.startmail.com>
- Add libetebase-devel to BuildRequires to enable the etesync resource for
  factory builds
* Wed Sep 20 2023 Christophe Marin <christophe@krop.fr>
- Add upstream changes to fix issues with the google resource
  (boo#1214714, kde#470820)
  * 0001-Revert-Revert-Use-config-plugin-instead-of-out-of-pr.patch
  * 0002-Revert-Revert-Fix-race-condition-when-building.patch
  * 0003-Actually-start-job-to-read-secret-key.patch
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Revert "Use config plugin instead of out of process config dialog" (kde#473897)
  * Revert "Fix race condition when building"
  * vcarddirresource: fix directory not being configured on start
  * icaldirresource: fix directory not being configured on start
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Fix race condition when building
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes since 23.04.3, only listing bugfixes:
  * Implement retrieveItems(Item::List) for googleresource (kde#448106)
  * Fix crash trying to access password of empty account (kde#435427)
  * Skip EWS items where there is no registered handler (kde#440831)
  * Fix Bug 467719 Font is erroneously hardcoded. (kde#467719)
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Implement retrieveItems(Item::List) for googleresource (kde#448106)
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Fix crash trying to access password of empty account (kde#435427)
  * Ignore infinite set
  * Skip EWS items where there is no registered handler (kde#440831)
  * Fix single-file-resources not reloading configuration at runtime (kde#425460)
- Drop patches, merged upstream:
  * 0001-Fix-single-file-resources-not-reloading-configuratio.patch
  * 0004-Skip-EWS-items-where-there-is-no-registered-handler.patch
  * 0006-Ignore-infite-set.patch
  * 0001-Fix-crash-trying-to-access-password-of-empty-account.patch
* Sat Apr 29 2023 Christophe Marin <christophe@krop.fr>
- Add upstream fixes:
  * 0001-Fix-single-file-resources-not-reloading-configuratio.patch
    (kde#425460)
  * 0004-Skip-EWS-items-where-there-is-no-registered-handler.patch
    (kde#440831)
  * 0006-Ignore-infite-set.patch (related: kde#445746, kde#454322)
  * 0001-Fix-crash-trying-to-access-password-of-empty-account.patch
    (kde#435427, boo#1187119)
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Thu Mar 16 2023 Enrico Belleri <idesmi@protonmail.com>
- Requires akonadi-server
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Too many changes to list here.
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- Changes since 21.12.2:
  * Apply patch for disable sync contact as it don't ported yet. (kde#449024)
- Drop patch, now upstream:
  * 0001-Apply-patch-for-disable-sync-contact-as-it-don-t-por.patch
* Wed Feb 16 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to Work around google calendar events breaking due to
  dropped Contacts API (kde#449024):
  * 0001-Apply-patch-for-disable-sync-contact-as-it-don-t-por.patch
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * pop3: Properly reload settings on configuration change (kde#447005)
  * POP3: Fix SSL connections (kde#446751)
  * Use QFormLayout here
- Drop upstream patch:
  * 0001-POP3-Fix-SSL-connections.patch
* Sun Dec 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream change to fix pop3 connections:
  * 0001-POP3-Fix-SSL-connections.patch (kde#446751)
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- Changes since 21.11.90:
  * Enable new GitLab CI on stable branch.
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Fix POP3 setup wizard defaults to unencrypted connections. (kde#423426)
  * const'ify pointer
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Too many changes since 21.08.3, only listing bugfixes:
  * Fix 444985: Wrong ports in akonadi_pop3_resource.pot (kde#444985)
  * BUG 442884: Fix DSN support (kde#442884)
  * fix UI elements being used before initialization (kde#439991)
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Changes since 21.08.1:
  * Consider the online state when attempting to reconnect
  * DAV resource: support exception incidences
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * It seems that code was not build before adding to MR
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- Changes since 21.07.90:
  * Revert "Start to port to qt5keychain"
  * Drop X-KDE-Keywords entries from kcm desktop files
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Changes since 21.07.80:
  * fix UI elements being used before initialization (kde#439991)
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * Port Google Groupware resources to QFormLayout
  * Improve wording in singlefileresource dialog
  * Remove frame from openxchange config dialog
  * Port Ical dir resources dialog to QFormLayout
  * Port SingleFileResource Config UI to QFormLayout
  * Define if we want to reply to all or reply to author
  * Use new NewMailNotifierReplyMessageJob
  * Add job for replying message
  * Allow to reply message
  * Clean up unneeded JSON parameter in kcoreaddons_add_plugin
  * Honor KDE Kiosk setting lineedit_reveal_password
  * std::chrono_literals
  * not necessary to search in each sub folder
  * Use more centric cmake code
  * Install in "pim/kcms/kaddressbook"
  * Embed JSON metadata in KIOSlaves
  * Remove obsolete .protocol files
  * Convert protocol files to JSON
  * Start to port to qt5keychain
  * Make compile with last kf5
  * Fix clazy warning
  * Unbreak Build
  * Modernize code
  * use forward declaration here
  * Remove unused includes
  * Make it compile with last kf5 version
  * Make doctools optional
  * In kf6 kde4 migration code will be removed
  * Port to QButtonGroup::idToggled
  * Remove unused include
  * Use QLineEdit here
  * Add a missing KService linkage
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * Make the EWS Configuration dialog fit on small screens (kde#436841)
  * Adjust the size of the iCal Calendar File properties dialog (kde#435871)
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- Changes since 20.11.90:
  * Fix Google Groupware segfault
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- No code change since 20.11.80
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Too many changes since 20.08.3, only listing bugfixes:
  * Fix crash in SessionPool::requestPassword (kde#415339)
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- No code change since 20.08.2
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- Changes since 20.08.1:
  * Also set Internal Date in ChangeItemTask::doStart AppendJob
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- No code change since 20.08.0
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- No code change since 20.07.90
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- Changes since 20.07.80:
  * Fix Bug 423426 - POP3 setup wizard defaults to unencrypted connections
  * Setup widget first
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Too many changes since 20.04.3, only listing bugfixes:
  * POP3: Remove the singleton pattern from Settings (kde#419726)
  * [resources/ews] Adjust name of root collection to the name of the resource (kde#413078)
  * [resources/ews] Save password to wallet (kde#393002)
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- Changes since 20.04.2:
  * Reduce kf5
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * [resources/maildir] Reload configuraton on configuration change (kde#416287)
  * IMAP: fix use-after free in ChangeItemTask
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * IMAP: fix use-after free in ChangeItemTask
  * Register IMAP D-Bus interfaces before the service gets registered
  * Adapt to KDAV changes
  * Fix compilation with more recent Qt 5.15
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * Fix cppcheck warning
  * Disable for the moment
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes since 19.12.3, only listing bugfixes:
  * [resources/maildir] Don't save "file:" schema to the config (kde#408354)
- Dropped patches, now upstream:
  * 0001-resources-maildir-Don-t-save-file-schema-to-the-conf.patch
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- No code change since 19.12.2
* Mon Mar  2 2020 Luca Beltrame <lbeltrame@kde.org>
- Add upstream patch to fix issues with "file:/" being prepended
  to maildir resources (kde#408354,kde#411269,kde#413588):
  * 0001-resources-maildir-Don-t-save-file-schema-to-the-conf.patch
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- No code change since 19.12.0
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Don't use nullptr as flag value
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- Changes since 19.11.80:
  * IMAP resource: do not prompt for password with GSSAPI auth (kde#383279)
  * Link to Qt5::Xml since this code uses QDomDocument.
  * Sanity-check collection path before performing recursive deletion
  * Set deprecation versions to Qt 5.13 and KF 5.63 for the release branch
- Dropped patches, now upstream:
  * 0001-Sanity-check-collection-path-before-performing-recur.patch
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes to list here.
* Mon Nov 18 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add 0001-Sanity-check-collection-path-before-performing-recur.patch to fix
  a potential data loss issue (kde#414178)
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- Changes since 19.08.2:
  * Prevent writing to calendar file if not in current KAlarm format
* Thu Oct 17 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update build requirements
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- Changes since 19.08.1:
  * Fix the dependencies on generated files differently. (kde#410474)
  * ews: fix unnecessary reauthentication prompts
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- No code change since 19.08.0
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- Changes since 19.07.90:
  * Adapt to KCalendarCore namespace change
  * Fix a build time race condition
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * Fix the license file.
- Dropped patches, now upstream:
  * fix-the-license-file.patch
* Mon Aug  5 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix a copy of the LGPLv3:
  * fix-the-license-file.patch
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
* Fri Jul 19 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use %%_kf5_debugdir for logging categories.
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- Changes since 19.04.2:
  * Improve debug
  * Bug 407882: For a new resource, attempt to read existing calendar file
  * Bug 407882: configure new KAlarm file resource correctly
  * Try to fix a race condition.
  * Fix configure lockfile settings
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- Changes since 19.04.1:
  * Make sure that we reload settings
  * Remove unused class member
  * Improve debug messages
  * Bug 407544: Fix crash when creating new KAlarm resource
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- No code changes since 19.04.0
* Wed May  8 2019 wbauer@tmo.at
- Add Qca-qt5 BuildRequires to enable public key authentification
  in the EWS resource
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Convert to camelcase include
  * Revert the kalarm changes and fix the race condition differently.
  * IMAPResource: Defer task if we get disconnected during login
  * Fix constness of Attributes, in preparation for changes in Akonadi
  * Update the comment.
  * Allow running the pimkolab tests.
  * Try to fix the FreeBSD build when ECM_ENABLE_SANITIZERS is enabled.
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Fix sort element
  * Make sure to delete it when action was done
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * Fix mem leak
  * Fix Bug 396820 - Buttons in new mail notifications don't work. (kde#396820)
  * Fix extract i18n
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * Fix Bug 399231 - Kmail uses a low resolution icon for the notification (kde#399231)
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * Remove not necessary header when we send mail
  * Maildispatcher: escape '<' and '>' in error messages.
  * Fix compilation with Qt 5.12
* Thu Sep 20 2018 lbeltrame@kde.org
- Unversion the syndication requirement now that it has been moved
  to Frameworks
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Fix crash when we didn't select a agent
  * USe nullptr
  * Fix gmail auth dialog popping up over and over again.
  * Remove these ones
  * Process IMAP Quota roots with associated quotas only
  * Fix array access bounds in IMAP resource (kde#396980)
* Sat Sep  1 2018 fabian@ritter-vogt.de
- Disable unnecessary WebKitWidgets dependency
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * None
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Too many changes to list here
- Dropped patches, now upstream:
  * 0001-Always-add-domain-delimiter-if-Domain-checkbox-is-se.patch
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * Don't try to EXPUNGE read-only mailboxes (kde#395417)
  * IMAP: pre-fill current password in the password dialog (kde#395964)
* Mon Jul  2 2018 stefan.bruens@rwth-aachen.de
- Fix EWS connection when server needs an empty domain, fix kde#388496, backport:
  Add 0001-Always-add-domain-delimiter-if-Domain-checkbox-is-se.patch
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * resources/ews: Fix saving passwords to KWallet (kde#393002)
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * IMAP resource: fix data loss on connection lost, depending on the current task
  * IMAP: Collection removal should be replayed on error.
  * IMAP Resource: handle disconnection before initial "OK" from server
  * Fix IMAP resource stuck if connection lost during Login.
  * Fix a bunch of typos in comments
  * Fix version
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * make sure to create unique filename in maildir resource
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * Fix method name
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Maildir: upload empty email bodies as a whitespace
  * Don't insert invalid google accounts into the access list
  * Fix duplicated entries in Google Calendar and Tasks resource settings dialog
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * DAV: fix Next button not enabled when typing password.
  * Add Sasl2_INCLUDE_DIRS to the inlclude directories of kdexoauth2
  * cmake: Strip comments from else()/endif()
  * Use ecm_install_icons instead of a loop
  * Use KDE_INSTALL_ICONDIR instead of CMAKE_INSTALL_PREFIX
* Thu Dec 14 2017 christophe@krop.fr
- Update license to GPL-2.0+ and GPL-3.0+
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * Adapt to Qt 5.10 rc2 API changes
  * Remove duplicate find_package(KPimGAPI ...) call
* Fri Dec  8 2017 fabian@ritter-vogt.de
- Remove libkolab-qt5-devel BuildDep
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * Fix error when generate contact
  * Fix POP3 mail fetch not finishing if there are no new messages but some old ones
  * IMAP: always set merge mode in RetrieveItemsTask
  * Fix check version
  * Recreate full URLs from partial URLs (kde#386985)
  * Fix message extraction in kdepim-runtime/resources/ews/wizard/
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Too many changes to list here
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * IMAP: add folder name in error message about select.
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Fix i18n
  * DAV: fix crash if Collection disappears during Item fetch (kde#360792)
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * IMAP: handle when RetrieveItemTask fails to find the message (kde#383951)
  * Kolab: fix warning "Object type not handled" for each tag/relation
  * Add missing HasLocalStorage attribute to mbox resource
* Sat Aug 12 2017 christophe@krop.fr
- Update summary and description
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Remove not necessary includes
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * IMAP: allow creating top-level folders it User namespace is empty (kde#339567)
  * Fix Bug 379155 - Imap resources crash when trying to open settings (kde#379155)
  * Add missing include
  * Enable by default store locally emails
- Drop upstreamed patches:
  * add-missing-include.patch
  * fix-crash-when-configuring-IMAP-resources.patch
  * IMAP-allow-creating-top-level-folders-if-User-namespace-is-empty.patch
* Sun Jun  4 2017 wbauer@tmo.at
- Add IMAP-allow-creating-top-level-folders-if-User-namespace-is-empty.patch
  to fix creating/deleting top-level folders on certain IMAP servers
  (kde#339576)
* Mon May 22 2017 wbauer@tmo.at
- Add add-missing-include.patch and
  fix-crash-when-configuring-IMAP-resources.patch to fix IMAP
  resources crashing when trying to open settings
  (kde#379155, boo#1040086)
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Fix build with CMake 3.8.
  * [IMAP] Fix migration to new Gmail authentication
  * [IMAP] Disable the Gmail special cases when compiled without XOAUTH
  * hide doc help item.
  * [IMAP] Fix missing connect() when restarting IDLE job
  * [IMAP] Fix IDLE support with GSSAPI authentication (kde#311456)
- Drop upstreamed patches:
  * disable-gmail-when-compiled-without-xoauth.patch
  * fix-idle-support-with-gssapi.patch
  * fix-migration-to-new-gmail-authentication.patch
  * fix-missing-connect-when-restarting-idle.patch
* Tue May  9 2017 wbauer@tmo.at
- Unconditionally obsolete kdepim4-runtime on all distributions, we
  don't support kdepim4 any more
* Sat Apr 22 2017 lbeltrame@kde.org
- Add upstream patches to fix different issues with IMAP:
  * disable-gmail-when-compiled-without-xoauth.patch
  * fix-idle-support-with-gssapi.patch
  * fix-migration-to-new-gmail-authentication.patch
  * fix-missing-connect-when-restarting-idle.patch
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * not necessary to use += operator here
  * Use directly QFileInfo::exists here
  * Remove unused method
  * Minor optimization
  * Add remote ID information to "Corrupt Event", to make debugging possible.
  * using QFileInfo::exists( ) here too
  * Improve debug message
  * Improve debug output for the MyRights noise (which shouldn't happen anymore ;)
  * SessionPool: set the namespaces variables from the namespace job.
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * Preserve icaldir resource/collection display name (kde#376379)
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
- Drop fix-data-loss-bug-in-ical.patch due to upstream inclusion
* Sat Dec 24 2016 tittiatcoke@gmail.com
- Add fix-data-loss-bug-in-ical.patch to prevent an critical
  data loss. The ical resource failed to create std.ics if it
  didn't exists.
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Thu Aug 25 2016 fabian@ritter-vogt.de
- Provide/Obsolete kio-pimlibs
* Tue Aug 23 2016 fabian@ritter-vogt.de
- Build only on architectures supported by libqt5-qtwebengine
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Wed Jul 27 2016 wbauer@tmo.at
- Cleanup build requirements
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Tue Jun 14 2016 wbauer@tmo.at
- Use shared-mime-info macros (boo#979301)
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
- Drop bko354056.diff due to upstream inclusion
* Wed Mar 30 2016 tittiatcoke@gmail.com
- Add upstream patch bko354056.diff to resolve issues with
  Courier IMAP servers (bko#354056)
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
- Drop patch due to upstream inclusion
  * switch-to-gid-based-merge.diff
* Mon Sep 14 2015 lbeltrame@kde.org
- Add switch-to-gid-based-merge.diff: upstream changes to fix IMAP
  syncing of non-email objects (fixes email syncing with Kolab
  servers)
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Sat Aug 29 2015 cgiboudeaux@gmx.com
- Change the license tag to GPL-2.0
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Initial version based on KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
